@@ -1,10 +1,14 @@
 import os
 import re
+import sys
+import logging
 import requests
 from pathlib import Path
 from unidecode import unidecode
 from xml.etree import ElementTree
 
+logger = logging.getLogger('poddl')
+
 
 def get(url, destination, limit=-1, summary=False):
     destination = os.path.expanduser(destination)
@@ -16,41 +20,41 @@ def get(url, destination, limit=-1, summary=False):
     try:
         os.mkdir(destination)
     except (PermissionError, FileNotFoundError):
-        print('Could not create directory "{0}/"'.format(destination))
-        exit(1)
+        logger.error('Could not create directory "{0}/"'.format(destination))
+        sys.exit(1)
     except FileExistsError:
         pass
 
-    print('Downloading files to "{0}"...'.format(destination))
+    logger.info('Downloading files to "{0}"...'.format(destination))
     
     for idx, item in enumerate(items, start=1):
         if 0 < limit < idx:
-            exit(0)
+            logger.info('Stopped at limit "{0}"'.format(limit))
+            sys.exit(0)
     
         ascii_title = re.sub(r'[^a-z0-9._\- ]', '', unidecode(item.find('title').text), flags=re.IGNORECASE)
     
         try:
             url = item.find('enclosure[@type="audio/mpeg"]').get('url')
         except AttributeError as e:
-            print('Could not find a podcast URL for "{0}'.format(ascii_title))
+            logger.warning('Could not find a podcast URL for "{0}'.format(ascii_title))
             continue
     
         if summary:
-            print('{0} ({1} of {2})'.format(ascii_title, idx, len(items)))
+            logger.info('{0} ({1} of {2})'.format(ascii_title, idx, len(items)))
         else:
             destination_path = os.path.join(destination, '{0}.mp3'.format(ascii_title))
     
             if os.path.exists(destination_path):
-                print('"{0}" already exists, skipping'.format(destination_path))
+                logger.info('"{0}" already exists, skipping'.format(destination_path))
                 continue
             else:
                 try:
                     Path(destination_path).touch()
                 except FileNotFoundError:
-                    print('Unable to write to directory "{0}/"'.format(destination))
-                    exit(1)
+                    sys.exit('Unable to write to directory "{0}/"'.format(destination))
     
-            print('Downloading "{0}" ({1} of {2})...'.format(ascii_title, idx, len(items)))
+            logger.info('Downloading "{0}" ({1} of {2})...'.format(ascii_title, idx, len(items)))
     
             r = requests.get(url)
     
